package com.example;

import com.azure.core.http.rest.PagedIterable;
import com.azure.data.appconfiguration.ConfigurationClient;
import com.azure.data.appconfiguration.ConfigurationClientBuilder;
import com.azure.data.appconfiguration.models.ConfigurationSetting;
import com.azure.data.appconfiguration.models.SettingSelector;
import com.example.service.AzureAppConfigService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

public class JavaAzureAppConfigApplication {

    private static final Logger LOGGER = LoggerFactory.getLogger(JavaAzureAppConfigApplication.class);
    private static final String APP_CONNECTION_STRING = System.getenv("APP_CONFIGURATION_CONNECTION_STRING");
    private static final String EXISTING_KEY = "config.message";
    private static final String NEW_KEY = "config.dataSource";

    public static void main(String[] args) {
        ConfigurationClient configurationClient = new ConfigurationClientBuilder().connectionString(APP_CONNECTION_STRING).buildClient();
        AzureAppConfigService azureAppConfigService = new AzureAppConfigService(configurationClient, new SettingSelector());
        String readValueByKey = azureAppConfigService.getValueByKey(EXISTING_KEY);
        LOGGER.info("Message: {}", readValueByKey);

        String writeValueByKey = azureAppConfigService.writeValueByKey(NEW_KEY, "Data Source URL");
        LOGGER.info("Data Source URL From Application: {}", writeValueByKey);

        PagedIterable<ConfigurationSetting> readAllKeyValue = azureAppConfigService.readAllKeyValue();
        readAllKeyValue.forEach(property -> LOGGER.info("Key: {} \t Value: {}", property.getKey(), property.getValue()));

        String deleteValueByKey = azureAppConfigService.deleteValueByKey(NEW_KEY);
        LOGGER.warn("[Key: {} \t Value: {}] has been removed successfully", NEW_KEY, deleteValueByKey);

        LOGGER.info("After Removing Key-Value Read All Values...");
        readAllKeyValue = azureAppConfigService.readAllKeyValue();
        readAllKeyValue.forEach(property -> LOGGER.info("Key: {} \t Value: {}", property.getKey(), property.getValue()));
    }
}
